
#line 3 "util/hostfile/hostfile_lex.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define yy_create_buffer orte_util_hostfile__create_buffer
#define yy_delete_buffer orte_util_hostfile__delete_buffer
#define yy_flex_debug orte_util_hostfile__flex_debug
#define yy_init_buffer orte_util_hostfile__init_buffer
#define yy_flush_buffer orte_util_hostfile__flush_buffer
#define yy_load_buffer_state orte_util_hostfile__load_buffer_state
#define yy_switch_to_buffer orte_util_hostfile__switch_to_buffer
#define yyin orte_util_hostfile_in
#define yyleng orte_util_hostfile_leng
#define yylex orte_util_hostfile_lex
#define yylineno orte_util_hostfile_lineno
#define yyout orte_util_hostfile_out
#define yyrestart orte_util_hostfile_restart
#define yytext orte_util_hostfile_text
#define yywrap orte_util_hostfile_wrap
#define yyalloc orte_util_hostfile_alloc
#define yyrealloc orte_util_hostfile_realloc
#define yyfree orte_util_hostfile_free

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 5
#define YY_FLEX_SUBMINOR_VERSION 35
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;
#endif /* ! C99 */

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#endif /* ! FLEXINT_H */

#ifdef __cplusplus

/* The "const" storage-class-modifier is valid. */
#define YY_USE_CONST

#else	/* ! __cplusplus */

/* C99 requires __STDC__ to be defined as 1. */
#if defined (__STDC__)

#define YY_USE_CONST

#endif	/* defined (__STDC__) */
#endif	/* ! __cplusplus */

#ifdef YY_USE_CONST
#define yyconst const
#else
#define yyconst
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an unsigned
 * integer for use as an array index.  If the signed char is negative,
 * we want to instead treat it as an 8-bit unsigned char, hence the
 * double cast.
 */
#define YY_SC_TO_UI(c) ((unsigned int) (unsigned char) c)

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *

/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START

/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)

/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE orte_util_hostfile_restart(orte_util_hostfile_in  )

#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#define YY_BUF_SIZE 16384
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

extern int orte_util_hostfile_leng;

extern FILE *orte_util_hostfile_in, *orte_util_hostfile_out;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2

    #define YY_LESS_LINENO(n)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up orte_util_hostfile_text. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up orte_util_hostfile_text again */ \
		} \
	while ( 0 )

#define unput(c) yyunput( c, (yytext_ptr)  )

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	yy_size_t yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */
    
	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via orte_util_hostfile_restart()), so that the user can continue scanning by
	 * just pointing orte_util_hostfile_in at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = 0; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)

/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* yy_hold_char holds the character lost when orte_util_hostfile_text is formed. */
static char yy_hold_char;
static int yy_n_chars;		/* number of characters read into yy_ch_buf */
int orte_util_hostfile_leng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = (char *) 0;
static int yy_init = 0;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow orte_util_hostfile_wrap()'s to do buffer switches
 * instead of setting up a fresh orte_util_hostfile_in.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

void orte_util_hostfile_restart (FILE *input_file  );
void orte_util_hostfile__switch_to_buffer (YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE orte_util_hostfile__create_buffer (FILE *file,int size  );
void orte_util_hostfile__delete_buffer (YY_BUFFER_STATE b  );
void orte_util_hostfile__flush_buffer (YY_BUFFER_STATE b  );
void orte_util_hostfile_push_buffer_state (YY_BUFFER_STATE new_buffer  );
void orte_util_hostfile_pop_buffer_state (void );

static void orte_util_hostfile_ensure_buffer_stack (void );
static void orte_util_hostfile__load_buffer_state (void );
static void orte_util_hostfile__init_buffer (YY_BUFFER_STATE b,FILE *file  );

#define YY_FLUSH_BUFFER orte_util_hostfile__flush_buffer(YY_CURRENT_BUFFER )

YY_BUFFER_STATE orte_util_hostfile__scan_buffer (char *base,yy_size_t size  );
YY_BUFFER_STATE orte_util_hostfile__scan_string (yyconst char *yy_str  );
YY_BUFFER_STATE orte_util_hostfile__scan_bytes (yyconst char *bytes,int len  );

void *orte_util_hostfile_alloc (yy_size_t  );
void *orte_util_hostfile_realloc (void *,yy_size_t  );
void orte_util_hostfile_free (void *  );

#define yy_new_buffer orte_util_hostfile__create_buffer

#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        orte_util_hostfile_ensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            orte_util_hostfile__create_buffer(orte_util_hostfile_in,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}

#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        orte_util_hostfile_ensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            orte_util_hostfile__create_buffer(orte_util_hostfile_in,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}

#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

typedef unsigned char YY_CHAR;

FILE *orte_util_hostfile_in = (FILE *) 0, *orte_util_hostfile_out = (FILE *) 0;

typedef int yy_state_type;

extern int orte_util_hostfile_lineno;

int orte_util_hostfile_lineno = 1;

extern char *orte_util_hostfile_text;
#define yytext_ptr orte_util_hostfile_text

static yy_state_type yy_get_previous_state (void );
static yy_state_type yy_try_NUL_trans (yy_state_type current_state  );
static int yy_get_next_buffer (void );
static void yy_fatal_error (yyconst char msg[]  );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up orte_util_hostfile_text.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	orte_util_hostfile_leng = (size_t) (yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	(yy_c_buf_p) = yy_cp;

#define YY_NUM_RULES 48
#define YY_END_OF_BUFFER 49
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static yyconst flex_int16_t yy_accept[251] =
    {   0,
       43,   43,    5,    5,   49,   47,   10,    1,   47,   47,
       43,   47,   47,   42,   43,   11,   43,   43,   43,   43,
       43,   43,   43,   43,   43,    5,    7,    6,   10,    1,
        0,    9,    0,    2,   43,   41,    0,    4,    0,   43,
        0,   42,   43,   43,   43,    0,   43,   43,   43,   46,
       43,   43,   43,   43,   43,   43,   43,   43,   43,   43,
        5,    6,    6,    8,    0,   39,    0,    3,    0,   42,
       43,   43,   43,   43,    0,    0,   43,   43,   43,   43,
       43,   43,   43,   43,   43,   12,   43,   43,   43,   43,
       43,   40,    0,    0,   42,   43,   43,   43,   43,   43,

        0,    0,   45,   43,   43,   43,   43,   43,   43,   43,
       43,   43,   43,   27,   28,   43,   43,    0,    0,   42,
       43,   43,   43,    0,   45,   43,   43,   43,   36,   13,
       43,   43,   43,   43,   43,   43,   14,   43,   43,   43,
       43,    0,    0,   43,   43,    0,   45,   43,   32,   43,
       43,   43,   43,   43,   43,   43,   43,   43,   43,   43,
       43,   43,   43,   43,   43,   43,   43,   44,    0,   45,
       43,   43,   43,   43,   19,   20,   43,   21,   43,   43,
       22,   43,   43,   43,   33,   43,   43,   43,   44,   43,
       43,   43,   43,   43,   43,   43,   43,   43,   43,   43,

       43,   43,   43,   29,   44,   43,   43,   23,   24,   25,
       17,   26,   18,   15,   16,   43,   43,   30,   31,   43,
       43,   43,   43,   43,   43,   43,   43,   43,   43,   43,
       43,   43,   43,   43,   43,   43,   43,   43,   43,   43,
       43,   43,   43,   38,   37,   43,   43,   35,   34,    0
    } ;

static yyconst flex_int32_t yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        2,    2,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    2,    1,    4,    5,    1,    1,    1,    1,    1,
        1,    6,    7,    8,    9,   10,   11,   12,   12,   12,
       12,   12,   12,   12,   12,   12,   12,   13,    1,    1,
       14,    1,    1,   15,   16,   16,   16,   16,   17,   16,
       18,   18,   18,   18,   18,   18,   18,   18,   18,   18,
       18,   18,   18,   18,   18,   18,   18,   18,   18,   18,
        8,    8,    8,   19,   20,    8,   21,   22,   23,   24,

       25,   16,   18,   18,   18,   18,   26,   27,   28,   29,
       30,   31,   18,   32,   33,   34,   35,   18,   18,   36,
       18,   18,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static yyconst flex_int32_t yy_meta[37] =
    {   0,
        1,    1,    2,    3,    1,    4,    1,    5,    6,    7,
        1,    8,    9,    1,    5,    8,    8,    6,    5,    6,
        8,    8,    8,    8,    8,    6,    6,    6,    6,    6,
        6,    6,    6,    6,    6,    6
    } ;

static yyconst flex_int16_t yy_base[269] =
    {   0,
        0,    0,   34,   35,  656,  657,   40,  657,  651,  651,
        0,   22,   38,   46,   79,  657,   99,  124,  144,  623,
       15,  631,  630,   23,  617,    0,  657,   78,   83,  657,
      645,  657,  645,  657,    0,  634,  634,  657,  642,  155,
      632,  169,    0,  189,  214,   44,  228,  242,    0,    0,
      256,  276,  622,   55,  607,  605,  611,  597,  603,  600,
        0,   82,   88,  657,  612,  606,  606,  657,  132,  284,
      298,  314,  334,  359,  595,   93,  373,    0,  387,  401,
      279,  415,  575,  581,  559,  134,  142,  555,  545,  549,
      537,  521,  520,  146,  126,  518,  429,  163,    0,  443,

      515,  156,  514,  457,  471,  513,  495,  485,  483,  486,
      485,  151,  166,    0,  479,  480,  284,  222,  494,  491,
      485,  490,  499,  486,  485,  478,  513,  457,  146,  237,
      468,  465,  152,  458,  157,  457,  251,  443,  447,  446,
      451,  459,  264,  457,  450,  449,  448,  445,    0,  426,
      425,  421,  420,  411,  408,  408,  407,  405,  399,  398,
      400,  401,  393,  387,  398,  395,  387,  402,  397,  393,
      380,  377,  380,  379,    0,    0,  364,    0,  358,  362,
        0,  354,  366,  365,  266,  351,  350,  352,  362,  341,
      316,  309,  305,  300,  300,  298,  296,  292,  289,  287,

      286,  291,  287,    0,  657,  302,  283,    0,    0,    0,
        0,    0,    0,    0,    0,  277,  274,    0,    0,  264,
      257,  256,  251,  240,  239,  253,  241,  233,  232,  226,
      225,  217,  216,  203,  199,  203,  178,  179,  175,  136,
      127,   81,   78,    0,    0,   74,   36,    0,    0,  657,
      538,  547,  556,  562,  568,  577,  586,  595,  602,  606,
      611,  613,  620,  622,  624,  626,  628,  630
    } ;

static yyconst flex_int16_t yy_def[269] =
    {   0,
      250,    1,  251,  251,  250,  250,  250,  250,  252,  253,
      254,  250,  250,  250,  254,  250,  250,   17,  255,   17,
       17,   18,   18,   18,   18,  256,  250,  257,  250,  250,
      252,  250,  253,  250,  254,  250,  250,  250,  258,   14,
      250,   14,   15,  250,   40,  259,  254,   15,   18,  260,
       17,  261,   18,   18,   18,   18,   18,   18,   18,   18,
      256,  257,  257,  250,  250,  250,  258,  250,  250,   14,
       45,  254,  250,   73,  262,  263,   47,   48,   47,   17,
      261,   44,   18,   18,   18,   18,   18,   18,   18,   18,
       18,  250,  250,  250,   40,   40,   72,   97,   74,   73,

      264,  263,  265,   47,   47,   18,   18,   18,   18,   18,
       18,   18,   18,   18,   18,   18,   18,  250,  250,   40,
       97,  121,   73,  266,  267,  254,   47,   18,   18,   18,
       18,   18,   18,   18,   18,   18,   18,   18,   18,   18,
       18,  250,  250,  254,   74,  250,  268,  254,   18,   18,
       18,   18,   18,   18,   18,   18,   18,   18,   18,   18,
       18,   18,   18,   18,   18,   18,   18,  250,  250,  250,
       18,   18,   18,   18,   18,   18,   18,   18,   18,   18,
       18,   18,   18,   18,   18,   18,   18,   18,  250,   18,
       18,   18,   18,   18,   18,   18,   18,   18,   18,   18,

       18,   18,   18,   18,  250,   18,   18,   18,   18,   18,
       18,   18,   18,   18,   18,   18,   18,   18,   18,   18,
       18,   18,   18,   18,   18,   18,   18,   18,   18,   18,
       18,   18,   18,   18,   18,   18,   18,   18,   18,   18,
       18,   18,   18,   18,   18,   18,   18,   18,   18,    0,
      250,  250,  250,  250,  250,  250,  250,  250,  250,  250,
      250,  250,  250,  250,  250,  250,  250,  250
    } ;

static yyconst flex_int16_t yy_nxt[694] =
    {   0,
        6,    7,    8,    9,   10,   11,   12,   11,   11,    6,
       13,   14,   15,   16,   11,   17,   17,   18,   19,   11,
       17,   20,   21,   17,   17,   18,   18,   22,   18,   18,
       18,   23,   24,   18,   25,   18,   27,   27,   36,   28,
       28,   29,   30,   38,   54,   55,   36,   46,   39,   58,
       37,   35,   59,   35,   40,   41,   76,   42,   43,  249,
       44,   45,   45,   40,   35,   40,   45,   45,   45,   45,
       45,   40,   40,   40,   40,   40,   40,   40,   40,   40,
       40,   40,   46,   63,   29,   30,   84,  250,   64,   85,
       47,   48,  250,   63,   47,   47,   46,  248,   64,   47,

       47,   47,   47,   47,   35,   76,   35,   49,   50,  247,
       51,   43,  246,   44,   51,   51,   49,   35,   49,   51,
       51,   51,   51,   51,   49,   49,   49,   49,   49,   49,
       49,   49,   49,   49,   49,   49,   35,  120,   43,   49,
       49,   93,  110,   94,   49,   49,   49,   49,   49,   35,
      112,   35,   35,  111,  150,   93,   35,  119,   35,  250,
      245,  113,   35,   35,  250,  151,   40,   35,  102,  244,
       40,   40,  250,  133,  122,   40,   40,   40,   40,   40,
       70,  156,  157,  134,   71,   71,  159,  160,  135,   71,
       71,   71,   71,   71,   35,  243,   35,   35,  136,  242,

       72,   43,  241,   35,   73,   73,   74,   35,   35,   73,
       73,   73,   73,   73,   74,   74,   74,   74,   74,   74,
       74,   74,   74,   74,   74,   71,   43,  240,  239,   71,
       71,  142,  238,  143,   71,   71,   71,   71,   71,   77,
       78,  237,  236,   77,   77,  152,  235,  234,   77,   77,
       77,   77,   77,   79,  233,  232,  153,   79,   79,  162,
      231,  230,   79,   79,   79,   79,   79,   80,  229,  228,
      163,   80,   80,  142,  200,  169,   80,   80,   80,   80,
       80,   35,  227,   35,   35,  201,   35,  226,   35,  225,
       82,   35,  139,   82,   35,   95,  224,   35,  223,   96,

       96,  222,  221,  140,   96,   96,   96,   96,   96,   96,
      220,  219,  141,   96,   96,  218,  217,  216,   96,   96,
       96,   96,   96,   41,  215,   97,   43,  214,  213,   98,
       98,  212,  211,  210,   98,   98,   98,   98,   98,   35,
      209,   35,   99,   50,  208,  100,   43,  207,   35,  100,
      100,   99,   35,   99,  100,  100,  100,  100,  100,   99,
       99,   99,   99,   99,   99,   99,   99,   99,   99,   99,
       99,   35,  206,  205,   99,   99,  204,  203,  202,   99,
       99,   99,   99,   99,  104,  199,  198,  197,  104,  104,
      196,  195,  194,  104,  104,  104,  104,  104,  105,  193,

      192,  191,  105,  105,  190,  102,  142,  105,  105,  105,
      105,  105,  106,  189,  188,  187,  106,  106,  186,  185,
      184,  106,  106,  106,  106,  106,   35,   35,  183,  182,
       74,   74,  181,  180,  179,   74,   74,   74,   74,   74,
      121,  178,  177,  176,  122,  122,  175,  174,  173,  122,
      122,  122,  122,  122,  123,  172,  171,   78,  123,  123,
      102,  102,   43,  123,  123,  123,  123,  123,  126,   43,
      168,  167,  126,  126,  166,  165,  164,  126,  126,  126,
      126,  126,  127,  161,  158,  155,  127,  127,  154,  149,
       78,  127,  127,  127,  127,  127,  144,  102,  102,  250,

      144,  144,  120,   93,  138,  144,  144,  144,  144,  144,
      145,  137,  132,  131,  145,  145,  130,  129,  128,  145,
      145,  145,  145,  145,  148,   43,  102,  102,  148,  148,
       43,  118,   92,  148,  148,  148,  148,  148,   26,   26,
       26,   26,   26,   26,   26,   26,   26,   31,   31,   31,
       31,   31,   31,   31,   31,   31,   33,   33,   33,   33,
       33,   33,   33,   33,   33,   35,   35,   35,  117,   35,
       35,   52,   52,   52,  116,   52,   52,   61,  115,   61,
      114,   61,   61,   61,   61,   61,   62,  109,   62,   62,
       62,   62,   62,   62,   62,   67,   67,   67,   67,   67,

       67,   67,   67,   67,   75,  108,  107,  102,   68,   75,
       75,   50,   50,   50,   81,   81,   81,   66,   81,   81,
      101,  101,  103,   92,   91,   90,   89,  103,  103,  124,
      124,  125,  125,  146,  146,  147,  147,  170,  170,   88,
       87,   86,   83,   69,   68,   66,   65,   34,   32,   60,
       57,   56,   53,   34,   32,  250,    5,  250,  250,  250,
      250,  250,  250,  250,  250,  250,  250,  250,  250,  250,
      250,  250,  250,  250,  250,  250,  250,  250,  250,  250,
      250,  250,  250,  250,  250,  250,  250,  250,  250,  250,
      250,  250,  250

    } ;

static yyconst flex_int16_t yy_chk[694] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    3,    4,   12,    3,
        4,    7,    7,   13,   21,   21,   12,   46,   13,   24,
       12,   14,   24,   14,   14,   14,   46,   14,   14,  247,
       14,   14,   14,   14,   14,   14,   14,   14,   14,   14,
       14,   14,   14,   14,   14,   14,   14,   14,   14,   14,
       14,   14,   15,   28,   29,   29,   54,   62,   28,   54,
       15,   15,   62,   63,   15,   15,   76,  246,   63,   15,

       15,   15,   15,   15,   17,   76,   17,   17,   17,  243,
       17,   17,  242,   17,   17,   17,   17,   17,   17,   17,
       17,   17,   17,   17,   17,   17,   17,   17,   17,   17,
       17,   17,   17,   17,   17,   18,   18,   95,   95,   18,
       18,   69,   86,   69,   18,   18,   18,   18,   18,   19,
       87,   19,   19,   86,  129,   94,   19,   94,   19,  102,
      241,   87,   19,   19,   40,  129,   40,   40,  102,  240,
       40,   40,   98,  112,   98,   40,   40,   40,   40,   40,
       42,  133,  133,  112,   42,   42,  135,  135,  113,   42,
       42,   42,   42,   42,   44,  239,   44,   44,  113,  238,

       44,   44,  237,   44,   44,   44,   44,   44,   44,   44,
       44,   44,   44,   44,   44,   44,   44,   44,   44,   44,
       44,   44,   44,   44,   44,   45,   45,  236,  235,   45,
       45,  118,  234,  118,   45,   45,   45,   45,   45,   47,
       47,  233,  232,   47,   47,  130,  231,  230,   47,   47,
       47,   47,   47,   48,  229,  228,  130,   48,   48,  137,
      227,  226,   48,   48,   48,   48,   48,   51,  225,  224,
      137,   51,   51,  143,  185,  143,   51,   51,   51,   51,
       51,   52,  223,   52,   81,  185,   81,  222,   52,  221,
       52,   81,  117,   81,   52,   70,  220,   81,  217,   70,

       70,  216,  207,  117,   70,   70,   70,   70,   70,   71,
      206,  203,  117,   71,   71,  202,  201,  200,   71,   71,
       71,   71,   71,   72,  199,   72,   72,  198,  197,   72,
       72,  196,  195,  194,   72,   72,   72,   72,   72,   73,
      193,   73,   73,   73,  192,   73,   73,  191,   73,   73,
       73,   73,   73,   73,   73,   73,   73,   73,   73,   73,
       73,   73,   73,   73,   73,   73,   73,   73,   73,   73,
       74,   74,  190,  189,   74,   74,  188,  187,  186,   74,
       74,   74,   74,   74,   77,  184,  183,  182,   77,   77,
      180,  179,  177,   77,   77,   77,   77,   77,   79,  174,

      173,  172,   79,   79,  171,  170,  169,   79,   79,   79,
       79,   79,   80,  168,  167,  166,   80,   80,  165,  164,
      163,   80,   80,   80,   80,   80,   82,   82,  162,  161,
       82,   82,  160,  159,  158,   82,   82,   82,   82,   82,
       97,  157,  156,  155,   97,   97,  154,  153,  152,   97,
       97,   97,   97,   97,  100,  151,  150,  148,  100,  100,
      147,  146,  145,  100,  100,  100,  100,  100,  104,  144,
      142,  141,  104,  104,  140,  139,  138,  104,  104,  104,
      104,  104,  105,  136,  134,  132,  105,  105,  131,  128,
      126,  105,  105,  105,  105,  105,  121,  125,  124,  122,

      121,  121,  120,  119,  116,  121,  121,  121,  121,  121,
      123,  115,  111,  110,  123,  123,  109,  108,  107,  123,
      123,  123,  123,  123,  127,  106,  103,  101,  127,  127,
       96,   93,   92,  127,  127,  127,  127,  127,  251,  251,
      251,  251,  251,  251,  251,  251,  251,  252,  252,  252,
      252,  252,  252,  252,  252,  252,  253,  253,  253,  253,
      253,  253,  253,  253,  253,  254,  254,  254,   91,  254,
      254,  255,  255,  255,   90,  255,  255,  256,   89,  256,
       88,  256,  256,  256,  256,  256,  257,   85,  257,  257,
      257,  257,  257,  257,  257,  258,  258,  258,  258,  258,

      258,  258,  258,  258,  259,   84,   83,   75,   67,  259,
      259,  260,  260,  260,  261,  261,  261,   66,  261,  261,
      262,  262,  263,   65,   60,   59,   58,  263,  263,  264,
      264,  265,  265,  266,  266,  267,  267,  268,  268,   57,
       56,   55,   53,   41,   39,   37,   36,   33,   31,   25,
       23,   22,   20,   10,    9,    5,  250,  250,  250,  250,
      250,  250,  250,  250,  250,  250,  250,  250,  250,  250,
      250,  250,  250,  250,  250,  250,  250,  250,  250,  250,
      250,  250,  250,  250,  250,  250,  250,  250,  250,  250,
      250,  250,  250

    } ;

static yy_state_type yy_last_accepting_state;
static char *yy_last_accepting_cpos;

extern int orte_util_hostfile__flex_debug;
int orte_util_hostfile__flex_debug = 0;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *orte_util_hostfile_text;
#line 1 "hostfile_lex.l"
#line 2 "hostfile_lex.l"
/*
 * Copyright (c) 2004-2005 The Trustees of Indiana University and Indiana
 *                         University Research and Technology
 *                         Corporation.  All rights reserved.
 * Copyright (c) 2004-2006 The University of Tennessee and The University
 *                         of Tennessee Research Foundation.  All rights
 *                         reserved.
 * Copyright (c) 2004-2005 High Performance Computing Center Stuttgart, 
 *                         University of Stuttgart.  All rights reserved.
 * Copyright (c) 2004-2005 The Regents of the University of California.
 *                         All rights reserved.
 * $COPYRIGHT$
 * 
 * Additional copyrights may follow
 * 
 * $HEADER$
 */
#include "orte_config.h"

#include <stdio.h>
#ifdef HAVE_UNISTD_H
#include <unistd.h>
#endif

#include "orte/util/hostfile/hostfile_lex.h"

/*
 * local functions
 */
BEGIN_C_DECLS

int orte_util_hostfile_wrap(void);

END_C_DECLS

int orte_util_hostfile_wrap(void)
{
    orte_util_hostfile_done = true;
    return 1;
}

/*
 * global variables
 */
int orte_util_hostfile_line=1;
orte_hostfile_value_t orte_util_hostfile_value;
bool orte_util_hostfile_done = false;


#line 755 "util/hostfile/hostfile_lex.c"

#define INITIAL 0
#define comment 1

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

static int yy_init_globals (void );

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int orte_util_hostfile_lex_destroy (void );

int orte_util_hostfile_get_debug (void );

void orte_util_hostfile_set_debug (int debug_flag  );

YY_EXTRA_TYPE orte_util_hostfile_get_extra (void );

void orte_util_hostfile_set_extra (YY_EXTRA_TYPE user_defined  );

FILE *orte_util_hostfile_get_in (void );

void orte_util_hostfile_set_in  (FILE * in_str  );

FILE *orte_util_hostfile_get_out (void );

void orte_util_hostfile_set_out  (FILE * out_str  );

int orte_util_hostfile_get_leng (void );

char *orte_util_hostfile_get_text (void );

int orte_util_hostfile_get_lineno (void );

void orte_util_hostfile_set_lineno (int line_number  );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int orte_util_hostfile_wrap (void );
#else
extern int orte_util_hostfile_wrap (void );
#endif
#endif

    static void yyunput (int c,char *buf_ptr  );
    
#ifndef yytext_ptr
static void yy_flex_strncpy (char *,yyconst char *,int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * );
#endif

#ifndef YY_NO_INPUT

#ifdef __cplusplus
static int yyinput (void );
#else
static int input (void );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#define YY_READ_BUF_SIZE 8192
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO fwrite( orte_util_hostfile_text, orte_util_hostfile_leng, 1, orte_util_hostfile_out )
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		int n; \
		for ( n = 0; n < max_size && \
			     (c = getc( orte_util_hostfile_in )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( orte_util_hostfile_in ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = fread(buf, 1, max_size, orte_util_hostfile_in))==0 && ferror(orte_util_hostfile_in)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(orte_util_hostfile_in); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int orte_util_hostfile_lex (void);

#define YY_DECL int orte_util_hostfile_lex (void)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after orte_util_hostfile_text and orte_util_hostfile_leng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK break;
#endif

#define YY_RULE_SETUP \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	register yy_state_type yy_current_state;
	register char *yy_cp, *yy_bp;
	register int yy_act;
    
#line 56 "hostfile_lex.l"


#line 941 "util/hostfile/hostfile_lex.c"

	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! orte_util_hostfile_in )
			orte_util_hostfile_in = stdin;

		if ( ! orte_util_hostfile_out )
			orte_util_hostfile_out = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			orte_util_hostfile_ensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				orte_util_hostfile__create_buffer(orte_util_hostfile_in,YY_BUF_SIZE );
		}

		orte_util_hostfile__load_buffer_state( );
		}

	while ( 1 )		/* loops until end-of-file is reached */
		{
		yy_cp = (yy_c_buf_p);

		/* Support of orte_util_hostfile_text. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = (yy_start);
yy_match:
		do
			{
			register YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)];
			if ( yy_accept[yy_current_state] )
				{
				(yy_last_accepting_state) = yy_current_state;
				(yy_last_accepting_cpos) = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 251 )
					yy_c = yy_meta[(unsigned int) yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
			++yy_cp;
			}
		while ( yy_base[yy_current_state] != 657 );

yy_find_action:
		yy_act = yy_accept[yy_current_state];
		if ( yy_act == 0 )
			{ /* have to back up */
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			yy_act = yy_accept[yy_current_state];
			}

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = (yy_hold_char);
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			goto yy_find_action;

case 1:
/* rule 1 can match eol */
YY_RULE_SETUP
#line 58 "hostfile_lex.l"
{ orte_util_hostfile_line++; 
                     return ORTE_HOSTFILE_NEWLINE; }
	YY_BREAK
case 2:
/* rule 2 can match eol */
YY_RULE_SETUP
#line 60 "hostfile_lex.l"
{ orte_util_hostfile_line++; 
                     return ORTE_HOSTFILE_NEWLINE; }
	YY_BREAK
case 3:
/* rule 3 can match eol */
YY_RULE_SETUP
#line 62 "hostfile_lex.l"
{ orte_util_hostfile_line++; 
                     return ORTE_HOSTFILE_NEWLINE; }
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 65 "hostfile_lex.l"
{ BEGIN(comment);
                     return ORTE_HOSTFILE_NEWLINE; }
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 67 "hostfile_lex.l"
; /* Eat up non '*'s */
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 68 "hostfile_lex.l"
; /* Eat '*'s not followed by a '/' */
	YY_BREAK
case 7:
/* rule 7 can match eol */
YY_RULE_SETUP
#line 69 "hostfile_lex.l"
{ orte_util_hostfile_line++;
                     return ORTE_HOSTFILE_NEWLINE; } 
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 71 "hostfile_lex.l"
{ BEGIN(INITIAL); /* Done with Block Comment */
                     return ORTE_HOSTFILE_NEWLINE; }
	YY_BREAK
case 9:
/* rule 9 can match eol */
YY_RULE_SETUP
#line 74 "hostfile_lex.l"
{ orte_util_hostfile_value.sval = orte_util_hostfile_text; 
                     return ORTE_HOSTFILE_QUOTED_STRING; }
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 77 "hostfile_lex.l"
;			/* whitespace */
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 79 "hostfile_lex.l"
{ return ORTE_HOSTFILE_EQUAL; }
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 81 "hostfile_lex.l"
{ orte_util_hostfile_value.sval = orte_util_hostfile_text; 
                     return ORTE_HOSTFILE_CPU; }
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 83 "hostfile_lex.l"
{ orte_util_hostfile_value.sval = orte_util_hostfile_text; 
                     return ORTE_HOSTFILE_COUNT; }
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 85 "hostfile_lex.l"
{ orte_util_hostfile_value.sval = orte_util_hostfile_text; 
                     return ORTE_HOSTFILE_SLOTS; }
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 87 "hostfile_lex.l"
{ orte_util_hostfile_value.sval = orte_util_hostfile_text; 
                     return ORTE_HOSTFILE_SLOTS_MAX; }
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 89 "hostfile_lex.l"
{ orte_util_hostfile_value.sval = orte_util_hostfile_text; 
                     return ORTE_HOSTFILE_SLOTS_MAX; }
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 91 "hostfile_lex.l"
{ orte_util_hostfile_value.sval = orte_util_hostfile_text; 
                     return ORTE_HOSTFILE_SLOTS_MAX; }
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 93 "hostfile_lex.l"
{ orte_util_hostfile_value.sval = orte_util_hostfile_text; 
                     return ORTE_HOSTFILE_SLOTS_MAX; }
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 95 "hostfile_lex.l"
{ orte_util_hostfile_value.sval = orte_util_hostfile_text; 
                     return ORTE_HOSTFILE_SLOTS_MAX; }
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 97 "hostfile_lex.l"
{ orte_util_hostfile_value.sval = orte_util_hostfile_text; 
                     return ORTE_HOSTFILE_SLOTS_MAX; }
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 99 "hostfile_lex.l"
{ orte_util_hostfile_value.sval = orte_util_hostfile_text; 
                     return ORTE_HOSTFILE_SLOTS_MAX; }
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 101 "hostfile_lex.l"
{ orte_util_hostfile_value.sval = orte_util_hostfile_text; 
                     return ORTE_HOSTFILE_SLOTS_MAX; }
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 103 "hostfile_lex.l"
{ orte_util_hostfile_value.sval = orte_util_hostfile_text; 
                     return ORTE_HOSTFILE_SLOTS_MAX; }
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 105 "hostfile_lex.l"
{ orte_util_hostfile_value.sval = orte_util_hostfile_text; 
                     return ORTE_HOSTFILE_SLOTS_MAX; }
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 107 "hostfile_lex.l"
{ orte_util_hostfile_value.sval = orte_util_hostfile_text; 
                     return ORTE_HOSTFILE_SLOTS_MAX; }
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 109 "hostfile_lex.l"
{ orte_util_hostfile_value.sval = orte_util_hostfile_text; 
                     return ORTE_HOSTFILE_SLOTS_MAX; }
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 112 "hostfile_lex.l"
{ orte_util_hostfile_value.sval = orte_util_hostfile_text; 
                     return ORTE_HOSTFILE_RANK; }
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 114 "hostfile_lex.l"
{ orte_util_hostfile_value.sval = orte_util_hostfile_text; 
                     return ORTE_HOSTFILE_SLOT; }
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 117 "hostfile_lex.l"
{ orte_util_hostfile_value.sval = orte_util_hostfile_text;
                     return ORTE_HOSTFILE_USERNAME; }
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 119 "hostfile_lex.l"
{ orte_util_hostfile_value.sval = orte_util_hostfile_text;
                     return ORTE_HOSTFILE_USERNAME; }
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 121 "hostfile_lex.l"
{ orte_util_hostfile_value.sval = orte_util_hostfile_text;
                     return ORTE_HOSTFILE_USERNAME; }
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 124 "hostfile_lex.l"
{ orte_util_hostfile_value.sval = orte_util_hostfile_text;
                     return ORTE_HOSTFILE_BOARDS; }
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 127 "hostfile_lex.l"
{ orte_util_hostfile_value.sval = orte_util_hostfile_text;
                     return ORTE_HOSTFILE_SOCKETS_PER_BOARD; }
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 130 "hostfile_lex.l"
{ orte_util_hostfile_value.sval = orte_util_hostfile_text;
                     return ORTE_HOSTFILE_SOCKETS_PER_BOARD; }
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 133 "hostfile_lex.l"
{ orte_util_hostfile_value.sval = orte_util_hostfile_text;
                     return ORTE_HOSTFILE_SOCKETS_PER_BOARD; }
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 136 "hostfile_lex.l"
{ orte_util_hostfile_value.sval = orte_util_hostfile_text;
                     return ORTE_HOSTFILE_CORES_PER_SOCKET; }
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 139 "hostfile_lex.l"
{ orte_util_hostfile_value.sval = orte_util_hostfile_text;
                     return ORTE_HOSTFILE_CORES_PER_SOCKET; }
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 142 "hostfile_lex.l"
{ orte_util_hostfile_value.sval = orte_util_hostfile_text;
                     return ORTE_HOSTFILE_CORES_PER_SOCKET; }
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 145 "hostfile_lex.l"
{ orte_util_hostfile_value.sval = orte_util_hostfile_text;
                     return ORTE_HOSTFILE_RELATIVE; }
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 147 "hostfile_lex.l"
{ orte_util_hostfile_value.sval = orte_util_hostfile_text;
                     return ORTE_HOSTFILE_RELATIVE; }
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 149 "hostfile_lex.l"
{ orte_util_hostfile_value.sval = orte_util_hostfile_text;
                     return ORTE_HOSTFILE_RELATIVE; }
	YY_BREAK
case 42:
YY_RULE_SETUP
#line 153 "hostfile_lex.l"
{ orte_util_hostfile_value.ival = atol(orte_util_hostfile_text); 
                     return ORTE_HOSTFILE_INT; }
	YY_BREAK
 /* First detect hosts as standard Strings (but without ".")
    * then username@IPv4 or IPV4, then username@IPv6 or IPv6,
    * followed by username@hostname or hostname
    */

case 43:
YY_RULE_SETUP
#line 161 "hostfile_lex.l"
{ orte_util_hostfile_value.sval = orte_util_hostfile_text;
                     return ORTE_HOSTFILE_STRING; }
	YY_BREAK
case 44:
YY_RULE_SETUP
#line 164 "hostfile_lex.l"
{
                      orte_util_hostfile_value.sval = orte_util_hostfile_text;
                      return ORTE_HOSTFILE_IPV4; }
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 168 "hostfile_lex.l"
{
                      orte_util_hostfile_value.sval = orte_util_hostfile_text;
                      return ORTE_HOSTFILE_IPV6; }
	YY_BREAK
case 46:
YY_RULE_SETUP
#line 172 "hostfile_lex.l"
{
                     orte_util_hostfile_value.sval = orte_util_hostfile_text; 
                     return ORTE_HOSTFILE_HOSTNAME; }
	YY_BREAK
case 47:
YY_RULE_SETUP
#line 176 "hostfile_lex.l"
{ orte_util_hostfile_value.sval = orte_util_hostfile_text; 
                     return ORTE_HOSTFILE_ERROR; }
	YY_BREAK
case 48:
YY_RULE_SETUP
#line 179 "hostfile_lex.l"
ECHO;
	YY_BREAK
#line 1320 "util/hostfile/hostfile_lex.c"
case YY_STATE_EOF(INITIAL):
case YY_STATE_EOF(comment):
	yyterminate();

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed orte_util_hostfile_in at a new source and called
			 * orte_util_hostfile_lex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = orte_util_hostfile_in;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_c_buf_p);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( orte_util_hostfile_wrap( ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * orte_util_hostfile_text, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
} /* end of orte_util_hostfile_lex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (void)
{
    	register char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	register char *source = (yytext_ptr);
	register int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr)) - 1;

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER;

			int yy_c_buf_p_offset =
				(int) ((yy_c_buf_p) - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				int new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					orte_util_hostfile_realloc((void *) b->yy_ch_buf,b->yy_buf_size + 2  );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = 0;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			(yy_c_buf_p) = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), (size_t) num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			orte_util_hostfile_restart(orte_util_hostfile_in  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if ((yy_size_t) ((yy_n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		yy_size_t new_size = (yy_n_chars) + number_to_move + ((yy_n_chars) >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) orte_util_hostfile_realloc((void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf,new_size  );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
	}

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (void)
{
	register yy_state_type yy_current_state;
	register char *yy_cp;
    
	yy_current_state = (yy_start);

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
		register YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			(yy_last_accepting_state) = yy_current_state;
			(yy_last_accepting_cpos) = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 251 )
				yy_c = yy_meta[(unsigned int) yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
{
	register int yy_is_jam;
    	register char *yy_cp = (yy_c_buf_p);

	register YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		(yy_last_accepting_state) = yy_current_state;
		(yy_last_accepting_cpos) = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 251 )
			yy_c = yy_meta[(unsigned int) yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
	yy_is_jam = (yy_current_state == 250);

	return yy_is_jam ? 0 : yy_current_state;
}

    static void yyunput (int c, register char * yy_bp )
{
	register char *yy_cp;
    
    yy_cp = (yy_c_buf_p);

	/* undo effects of setting up orte_util_hostfile_text */
	*yy_cp = (yy_hold_char);

	if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
		{ /* need to shift things up to make room */
		/* +2 for EOB chars. */
		register int number_to_move = (yy_n_chars) + 2;
		register char *dest = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[
					YY_CURRENT_BUFFER_LVALUE->yy_buf_size + 2];
		register char *source =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move];

		while ( source > YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			*--dest = *--source;

		yy_cp += (int) (dest - source);
		yy_bp += (int) (dest - source);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars =
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_buf_size;

		if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
			YY_FATAL_ERROR( "flex scanner push-back overflow" );
		}

	*--yy_cp = (char) c;

	(yytext_ptr) = yy_bp;
	(yy_hold_char) = *yy_cp;
	(yy_c_buf_p) = yy_cp;
}

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			int offset = (yy_c_buf_p) - (yytext_ptr);
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					orte_util_hostfile_restart(orte_util_hostfile_in );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( orte_util_hostfile_wrap( ) )
						return EOF;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve orte_util_hostfile_text */
	(yy_hold_char) = *++(yy_c_buf_p);

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void orte_util_hostfile_restart  (FILE * input_file )
{
    
	if ( ! YY_CURRENT_BUFFER ){
        orte_util_hostfile_ensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            orte_util_hostfile__create_buffer(orte_util_hostfile_in,YY_BUF_SIZE );
	}

	orte_util_hostfile__init_buffer(YY_CURRENT_BUFFER,input_file );
	orte_util_hostfile__load_buffer_state( );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void orte_util_hostfile__switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		orte_util_hostfile_pop_buffer_state();
	 *		orte_util_hostfile_push_buffer_state(new_buffer);
     */
	orte_util_hostfile_ensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	orte_util_hostfile__load_buffer_state( );

	/* We don't actually know whether we did this switch during
	 * EOF (orte_util_hostfile_wrap()) processing, but the only time this flag
	 * is looked at is after orte_util_hostfile_wrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

static void orte_util_hostfile__load_buffer_state  (void)
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	orte_util_hostfile_in = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE orte_util_hostfile__create_buffer  (FILE * file, int  size )
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) orte_util_hostfile_alloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in orte_util_hostfile__create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) orte_util_hostfile_alloc(b->yy_buf_size + 2  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in orte_util_hostfile__create_buffer()" );

	b->yy_is_our_buffer = 1;

	orte_util_hostfile__init_buffer(b,file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with orte_util_hostfile__create_buffer()
 * 
 */
    void orte_util_hostfile__delete_buffer (YY_BUFFER_STATE  b )
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		orte_util_hostfile_free((void *) b->yy_ch_buf  );

	orte_util_hostfile_free((void *) b  );
}

#ifndef __cplusplus
extern int isatty (int );
#endif /* __cplusplus */
    
/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a orte_util_hostfile_restart() or at EOF.
 */
    static void orte_util_hostfile__init_buffer  (YY_BUFFER_STATE  b, FILE * file )

{
	int oerrno = errno;
    
	orte_util_hostfile__flush_buffer(b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then orte_util_hostfile__init_buffer was _probably_
     * called from orte_util_hostfile_restart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = file ? (isatty( fileno(file) ) > 0) : 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void orte_util_hostfile__flush_buffer (YY_BUFFER_STATE  b )
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		orte_util_hostfile__load_buffer_state( );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void orte_util_hostfile_push_buffer_state (YY_BUFFER_STATE new_buffer )
{
    	if (new_buffer == NULL)
		return;

	orte_util_hostfile_ensure_buffer_stack();

	/* This block is copied from orte_util_hostfile__switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from orte_util_hostfile__switch_to_buffer. */
	orte_util_hostfile__load_buffer_state( );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void orte_util_hostfile_pop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	orte_util_hostfile__delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		orte_util_hostfile__load_buffer_state( );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void orte_util_hostfile_ensure_buffer_stack (void)
{
	int num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
		num_to_alloc = 1;
		(yy_buffer_stack) = (struct yy_buffer_state**)orte_util_hostfile_alloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in orte_util_hostfile_ensure_buffer_stack()" );
								  
		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));
				
		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		int grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)orte_util_hostfile_realloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in orte_util_hostfile_ensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object. 
 */
YY_BUFFER_STATE orte_util_hostfile__scan_buffer  (char * base, yy_size_t  size )
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return 0;

	b = (YY_BUFFER_STATE) orte_util_hostfile_alloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in orte_util_hostfile__scan_buffer()" );

	b->yy_buf_size = size - 2;	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = 0;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	orte_util_hostfile__switch_to_buffer(b  );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to orte_util_hostfile_lex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       orte_util_hostfile__scan_bytes() instead.
 */
YY_BUFFER_STATE orte_util_hostfile__scan_string (yyconst char * yystr )
{
    
	return orte_util_hostfile__scan_bytes(yystr,strlen(yystr) );
}

/** Setup the input buffer state to scan the given bytes. The next call to orte_util_hostfile_lex() will
 * scan from a @e copy of @a bytes.
 * @param bytes the byte buffer to scan
 * @param len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE orte_util_hostfile__scan_bytes  (yyconst char * yybytes, int  _yybytes_len )
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = _yybytes_len + 2;
	buf = (char *) orte_util_hostfile_alloc(n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in orte_util_hostfile__scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = orte_util_hostfile__scan_buffer(buf,n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in orte_util_hostfile__scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yy_fatal_error (yyconst char* msg )
{
    	(void) fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up orte_util_hostfile_text. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		orte_util_hostfile_text[orte_util_hostfile_leng] = (yy_hold_char); \
		(yy_c_buf_p) = orte_util_hostfile_text + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		orte_util_hostfile_leng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current line number.
 * 
 */
int orte_util_hostfile_get_lineno  (void)
{
        
    return orte_util_hostfile_lineno;
}

/** Get the input stream.
 * 
 */
FILE *orte_util_hostfile_get_in  (void)
{
        return orte_util_hostfile_in;
}

/** Get the output stream.
 * 
 */
FILE *orte_util_hostfile_get_out  (void)
{
        return orte_util_hostfile_out;
}

/** Get the length of the current token.
 * 
 */
int orte_util_hostfile_get_leng  (void)
{
        return orte_util_hostfile_leng;
}

/** Get the current token.
 * 
 */

char *orte_util_hostfile_get_text  (void)
{
        return orte_util_hostfile_text;
}

/** Set the current line number.
 * @param line_number
 * 
 */
void orte_util_hostfile_set_lineno (int  line_number )
{
    
    orte_util_hostfile_lineno = line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param in_str A readable stream.
 * 
 * @see orte_util_hostfile__switch_to_buffer
 */
void orte_util_hostfile_set_in (FILE *  in_str )
{
        orte_util_hostfile_in = in_str ;
}

void orte_util_hostfile_set_out (FILE *  out_str )
{
        orte_util_hostfile_out = out_str ;
}

int orte_util_hostfile_get_debug  (void)
{
        return orte_util_hostfile__flex_debug;
}

void orte_util_hostfile_set_debug (int  bdebug )
{
        orte_util_hostfile__flex_debug = bdebug ;
}

static int yy_init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from orte_util_hostfile_lex_destroy(), so don't allocate here.
     */

    (yy_buffer_stack) = 0;
    (yy_buffer_stack_top) = 0;
    (yy_buffer_stack_max) = 0;
    (yy_c_buf_p) = (char *) 0;
    (yy_init) = 0;
    (yy_start) = 0;

/* Defined in main.c */
#ifdef YY_STDINIT
    orte_util_hostfile_in = stdin;
    orte_util_hostfile_out = stdout;
#else
    orte_util_hostfile_in = (FILE *) 0;
    orte_util_hostfile_out = (FILE *) 0;
#endif

    /* For future reference: Set errno on error, since we are called by
     * orte_util_hostfile_lex_init()
     */
    return 0;
}

/* orte_util_hostfile_lex_destroy is for both reentrant and non-reentrant scanners. */
int orte_util_hostfile_lex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		orte_util_hostfile__delete_buffer(YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		orte_util_hostfile_pop_buffer_state();
	}

	/* Destroy the stack itself. */
	orte_util_hostfile_free((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * orte_util_hostfile_lex() is called, initialization will occur. */
    yy_init_globals( );

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, yyconst char * s2, int n )
{
	register int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * s )
{
	register int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *orte_util_hostfile_alloc (yy_size_t  size )
{
	return (void *) malloc( size );
}

void *orte_util_hostfile_realloc  (void * ptr, yy_size_t  size )
{
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return (void *) realloc( (char *) ptr, size );
}

void orte_util_hostfile_free (void * ptr )
{
	free( (char *) ptr );	/* see orte_util_hostfile_realloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 179 "hostfile_lex.l"



